Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Color ¶
Color defines background/forground color and attributes for text. The 'Clobber' bool says to color this pattern even if it is nested within another.
type Config ¶
type Config struct {
TabString string
TabString_set bool
TabWidth int
TabWidth_set bool
AutoTab bool
AutoTab_set bool
TabDetect bool
TabDetect_set bool
FmtCmd string
FmtCmd_set bool
Parent string
ExtMap map[string]string
SyntaxRules map[string]Color
FileConfigs map[string]Config
}
Config holds all configuration data. It will be read in from a config file. Elementary values each have a boolean *_set variable to mark a variable as set.
func CreateConfig ¶
func CreateConfig() Config
func (Config) MergeParent ¶
MergeParent merges the parent config into the child config. It does this recursively.
Click to show internal directories.
Click to hide internal directories.