Documentation
¶
Overview ¶
Package autocomplete provides basic autocompletion functionality. It takes in a set of files and creates a completer based on all the file contents.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetCommonPrefix ¶
GetCommonPrefix looks for the longest common prefix of a set of strings.
Types ¶
type AutoComplete ¶
type AutoComplete struct {
// contains filtered or unexported fields
}
func New ¶
func New() *AutoComplete
func (*AutoComplete) Complete ¶
func (ac *AutoComplete) Complete(prefix string, corpora ...string) []string
func (*AutoComplete) GetCommonPrefix ¶
func (ac *AutoComplete) GetCommonPrefix(matches []string) string
Click to show internal directories.
Click to hide internal directories.